==> apache-inlong-1.3.0-src.tar.gz: apache-inlong-1.3.0/inlong-agent/agent-plugins/src/main/java/org/apache/inlong/agent/plugin/filter/DateFormatRegex.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.filter;

import org.apache.commons.lang3.StringUtils;
import org.apache.inlong.agent.plugin.Filter;
import org.apache.inlong.agent.utils.AgentUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * date format with regex string for absolute file path.
 */
public class DateFormatRegex implements Filter {

    private static final Logger LOGGER = LoggerFactory.getLogger(DateFormatRegex.class);

    private static final String YEAR = "YYYY";
    private static final String MONTH = "MM";
    private static final String DAY = "DD";
    private static final String HOUR = "HH";

    private static final String NORMAL_FORMATTER = "yyyyMMddHHmm";

    private static final String OFFSET_DAY = "d";
    private static final String OFFSET_MIN = "m";
    private static final String OFFSET_HOUR = "h";

    private int dayOffset = 0;
    private int hourOffset = 0;
    private int minuteOffset = 0;

    private String formattedTime = "";
    private String formattedRegex;
    private File file;

    /**
     * set regex with current time
     */
    public static DateFormatRegex ofRegex(String regex) {
        DateFormatRegex dateFormatRegex = new DateFormatRegex();
        dateFormatRegex.setRegexWithCurrentTime(regex);
        return dateFormatRegex;
    }

    @Override
    public boolean match() {
        // TODO: check with more regex
        return AgentUtils.regexMatch(file.getAbsolutePath(), formattedRegex);
    }

    /**
     * set timeOffset
     */
    public DateFormatRegex withOffset(String timeOffset) {
        String number = StringUtils.substring(timeOffset, 0, timeOffset.length() - 1);
        String mark = StringUtils.substring(timeOffset, timeOffset.length() - 1);
        switch (mark) {
            case OFFSET_DAY:
                dayOffset = Integer.parseInt(number);
                break;
            case OFFSET_HOUR:
                hourOffset = Integer.parseInt(number);
                break;
            case OFFSET_MIN:
                minuteOffset = Integer.parseInt(number);
                break;
            default:
                LOGGER.warn("time offset is invalid, please check {}", timeOffset);
                break;
        }
        return this;
    }

    public DateFormatRegex withFile(File file) {
        this.file = file;
        return this;
    }

    /**
     * set regex with given time, replace the YYYYDDMM pattern with given time
     */
    public void setRegexWithTime(String regex, String time) {
        String[] regexList = StringUtils.splitByWholeSeparatorPreserveAllTokens(regex,
                File.separator, 0);
        List<String> formattedList = new ArrayList<>();
        for (String regexStr : regexList) {
            if (regexStr.contains(YEAR)) {
                String tmpRegexStr = regexStr.replace(YEAR, time.substring(0, 4))
                        .replace(MONTH, time.substring(4, 6))
                        .replace(DAY, time.substring(6, 8))
                        .replace(HOUR, time.substring(8, 10));
                formattedList.add(tmpRegexStr);
                formattedTime = time;
            } else {
                formattedList.add(regexStr);
            }
        }
        this.formattedRegex = StringUtils.join(formattedList, File.separatorChar);
        LOGGER.info("updated formatted regex is {}", this.formattedRegex);
    }

    /**
     * set regex with current time, replace the YYYYDDMM pattern with current time
     */
    public void setRegexWithCurrentTime(String regex) {
        String currentTime = AgentUtils.formatCurrentTimeWithOffset(NORMAL_FORMATTER,
                dayOffset, hourOffset, minuteOffset);
        setRegexWithTime(regex, currentTime);
    }

    public String getFormattedRegex() {
        return formattedRegex;
    }

    public String getFormattedTime() {
        return formattedTime;
    }
}

==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-agent/agent-plugins/src/main/java/org/apache/inlong/agent/plugin/filter/DateFormatRegex.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.filter;

import org.apache.commons.lang3.StringUtils;
import org.apache.inlong.agent.plugin.Filter;
import org.apache.inlong.agent.utils.AgentUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * date format with regex string for absolute file path.
 */
public class DateFormatRegex implements Filter {

    private static final Logger LOGGER = LoggerFactory.getLogger(DateFormatRegex.class);

    private static final String YEAR = "YYYY";
    private static final String YEAR_LOWERCASE = "yyyy";
    private static final String MONTH = "MM";
    private static final String DAY = "DD";
    private static final String DAY_LOWERCASE = "dd";
    private static final String HOUR = "HH";
    private static final String MINUTE = "mm";

    private static final String NORMAL_FORMATTER = "yyyyMMddHHmm";

    private static final String OFFSET_DAY = "d";
    private static final String OFFSET_MIN = "m";
    private static final String OFFSET_HOUR = "h";

    private int dayOffset = 0;
    private int hourOffset = 0;
    private int minuteOffset = 0;

    private String formattedTime = "";
    private String formattedRegex;
    private File file;

    /**
     * set regex with current time
     */
    public static DateFormatRegex ofRegex(String regex) {
        DateFormatRegex dateFormatRegex = new DateFormatRegex();
        dateFormatRegex.setRegexWithCurrentTime(regex);
        return dateFormatRegex;
    }

    @Override
    public boolean match() {
        // TODO: check with more regex
        return AgentUtils.regexMatch(file.getAbsolutePath(), formattedRegex);
    }

    /**
     * set timeOffset
     */
    public DateFormatRegex withOffset(String timeOffset) {
        String number = StringUtils.substring(timeOffset, 0, timeOffset.length() - 1);
        String mark = StringUtils.substring(timeOffset, timeOffset.length() - 1);
        switch (mark) {
            case OFFSET_DAY:
                dayOffset = Integer.parseInt(number);
                break;
            case OFFSET_HOUR:
                hourOffset = Integer.parseInt(number);
                break;
            case OFFSET_MIN:
                minuteOffset = Integer.parseInt(number);
                break;
            default:
                LOGGER.warn("time offset is invalid, please check {}", timeOffset);
                break;
        }
        return this;
    }

    public DateFormatRegex withFile(File file) {
        this.file = file;
        return this;
    }

    /**
     * set regex with given time, replace the YYYYDDMM pattern with given time
     */
    public void setRegexWithTime(String regex, String time) {
        String[] regexList = StringUtils.splitByWholeSeparatorPreserveAllTokens(regex,
                File.separator, 0);
        List<String> formattedList = new ArrayList<>();
        for (String regexStr : regexList) {
            if (regexStr.contains(YEAR) || regexStr.contains(YEAR_LOWERCASE)) {
                String tmpRegexStr = regexStr.replace(YEAR, time.substring(0, 4))
                        .replace(YEAR_LOWERCASE,time.substring(0, 4))
                        .replace(MONTH, time.substring(4, 6))
                        .replace(DAY, time.substring(6, 8))
                        .replace(DAY_LOWERCASE,time.substring(6, 8))
                        .replace(HOUR, time.substring(8, 10))
                        .replace(MINUTE,time.substring(10));
                formattedList.add(tmpRegexStr);
                formattedTime = time;
            } else {
                formattedList.add(regexStr);
            }
        }
        this.formattedRegex = StringUtils.join(formattedList, File.separatorChar);
        LOGGER.info("updated formatted regex is {}", this.formattedRegex);
    }

    /**
     * set regex with current time, replace the YYYYDDMM pattern with current time
     */
    public void setRegexWithCurrentTime(String regex) {
        String currentTime = AgentUtils.formatCurrentTimeWithOffset(NORMAL_FORMATTER,
                dayOffset, hourOffset, minuteOffset);
        setRegexWithTime(regex, currentTime);
    }

    public String getFormattedRegex() {
        return formattedRegex;
    }

    public String getFormattedTime() {
        return formattedTime;
    }
}
